@@ -22,4 +22,15 @@ class BaseConfig(BaseModel, ABC):
             yaml.safe_dump(self.to_dict(), f, default_flow_style=False, allow_unicode=True)
     
     def to_dict(self) -> Dict[str, Any]:
-        return self.model_dump() 
\ No newline at end of file
+        return self.model_dump() 
+
+    @property
+    def has_none(self):
+        # recursively check if any attribute is None
+        for attr, value in self.model_dump().items():
+            if value is None:
+                return True
+            if isinstance(value, BaseConfig):
+                if value.has_none:
+                    return True
+        return False
\ No newline at end of file
